﻿using Syncfusion.SfCalendar.XForms;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Text;
using Xamarin.Forms;
namespace SpecialDateSample
{
    public class CalendarViewModel : INotifyPropertyChanged
    {
        private CalendarEventCollection appointments;
        private ObservableCollection<string> meetingSubjectCollection;

        public Dictionary<string, CalendarEventCollection> DataSourceDictionary { get; set; } = new Dictionary<string, CalendarEventCollection>();

        public CalendarEventCollection Appointments
        {
            get
            {
                return this.appointments;
            }

            set
            {
                this.appointments = value;
                this.RaiseOnPropertyChanged("Appointments");
            }
        }


        public event PropertyChangedEventHandler PropertyChanged;


        public CalendarViewModel()
        {
            this.Appointments = new CalendarEventCollection();
            this.AddAppointmentDetails();
            this.AddAppointments();
        }

        private void AddAppointmentDetails()
        {
            meetingSubjectCollection = new ObservableCollection<string>();
            meetingSubjectCollection.Add("Planning");
            meetingSubjectCollection.Add("Meeting");
            meetingSubjectCollection.Add("Retrospective");
            meetingSubjectCollection.Add("Birthday");

        }

        private void AddAppointments()
        {
            var today = DateTime.Now.Date;
            var random = new Random();
            for (int month = -1; month < 2; month++)
            {
                for (int day = -5; day < 5; day++)
                {
                    for (int count = 0; count < 2; count++)
                    {
                        var appointment = new CalendarInlineEvent();
                        appointment.Subject = meetingSubjectCollection[random.Next(meetingSubjectCollection.Count)];
                        appointment.StartTime = today.AddMonths(month).AddDays(random.Next(1, 28)).AddHours(random.Next(9, 18));
                        appointment.EndTime = appointment.StartTime.AddHours(2);
                        this.Appointments.Add(appointment);
                        var key = appointment.StartTime.ToString("dd/MM/yyyy");

                        if (!this.DataSourceDictionary.ContainsKey(key))
                            this.DataSourceDictionary.Add(key, new CalendarEventCollection() { appointment });
                        else
                            this.DataSourceDictionary[key].Add(appointment);

                    }
                }
            }

        }

        private void RaiseOnPropertyChanged(string propertyName)
        {
            this.PropertyChanged?.Invoke(this, new PropertyChangedEventArgs(propertyName));
        }

    }
}
